@@ -10,18 +10,13 @@ log: logging.Logger = logging.getLogger(__name__)
 
 
 class Image:
-    def __init__(self, service_file, image_content=None, image_uri=None) -> None:
+    def __init__(self, service_file: str, image_uri: str) -> None:
         self.google = vision.ImageAnnotatorClient(
             credentials=service_account.Credentials.from_service_account_file(service_file)
         )
 
         self.image = types.Image()
-        if image_content:
-            self.image.content = image_content
-        elif image_uri:
-            self.image.source.image_uri = image_uri
-        else:
-            raise AttributeError("Please define either image_uri or image_content")
+        self.image.source.image_uri = image_uri
 
     def get_text(self) -> None:
         log.info("Requesting TEXT_DETECTION from Google Cloud API. This will cost us 0.0015 USD.")
