@@ -2,24 +2,46 @@ import datetime
 import decimal
 import json
 import logging
+import math
 import os
 import re
+from io import BytesIO
 from string import digits
 from typing import Optional
 
+import requests
 from babel import Locale
 from babel.numbers import get_group_symbol, NumberFormatError
 from dateutil.parser import parse as parse_date
+from PIL import Image as PILImage
 
 from .cloudvision import Image
 from .numbers import parse_decimal, parse_number
 
 log: logging.Logger = logging.getLogger(__name__)
 
+TEAMLESS = 0
+MYSTIC = 1
+VALOR = 2
+INSTINCT = 3
+
+TEAM_COLOURS = (
+    (None, (0, 0, 0)),
+    (None, (159, 228, 163)),  # Friends List Page
+    (None, (160, 208, 150)),  # Badge Pages
+    (TEAMLESS, (0.0, 231.0, 181.0)),
+    (MYSTIC, (6.5, 118.8, 241.6)),
+    (VALOR, (255.0, 4.0, 42.0)),
+    (INSTINCT, (253.0, 202.0, 0.1)),
+)
+
 
 class ProfileSelf(Image):
-    def __init__(self, service_file, image_content=None, image_uri=None) -> None:
-        super().__init__(service_file, image_content=image_content, image_uri=image_uri)
+    def __init__(self, service_file: str, image_uri: str) -> None:
+        super().__init__(service_file, image_uri)
+        self.pilimage = PILImage.open(BytesIO(requests.get(image_uri).content))
+        self.pilimage = self.pilimage.convert(mode="RGB")
+        self._team = None
         self.locale = Locale.parse("en")
         self.numeric_locale = {}
         with open(os.path.join(os.path.dirname(__file__), "pattern_lookups.json"), "r") as f:
@@ -56,7 +78,7 @@ class ProfileSelf(Image):
         try:
             travel_km = (
                 re.search(
-                    self.pattern_lookups[self.locale.language]["travel_km"],
+                    self.pattern_lookups[self.locale.language]["travel_km"] + "\s?[;:：]?\n(.+)",
                     self.text_found[0].description,
                     re.IGNORECASE,
                 )[1]
@@ -77,7 +99,7 @@ class ProfileSelf(Image):
             try:
                 total_xp = (
                     re.search(
-                        self.pattern_lookups[self.locale.language]["total_xp"],
+                        self.pattern_lookups[self.locale.language]["total_xp"] + "\s?[;:：]?\n(.+)",
                         self.text_found[0].description,
                         re.IGNORECASE,
                     )[1]
@@ -91,6 +113,24 @@ class ProfileSelf(Image):
                 translated = total_xp.translate(str.maketrans("", "", digits))
                 self.numeric_locale["group"] = translated[0]
 
+    def _calculate_colour_distance(self, c1, c2):
+        (r1, g1, b1) = c1
+        (r2, g2, b2) = c2
+        return math.sqrt((r1 - r2) ** 2 + (g1 - g2) ** 2 + (b1 - b2) ** 2)
+
+    def get_team(self) -> int:
+        # Get the pixel in the middle, 2 pixels in
+        # This is because the game adds borders to your profile to match your team colour
+        pixel_location = (2, self.pilimage.size[1] / 2)
+        rgb = self.pilimage.getpixel(pixel_location)
+        closest_colours = sorted(
+            TEAM_COLOURS, key=lambda colour: self._calculate_colour_distance(colour[1], rgb)
+        )
+        log.debug(f"RGB: {rgb}")
+        log.debug(f"Guesses: {closest_colours}")
+        best_guess = closest_colours[0][0]
+        return best_guess
+
     @property
     def username(self) -> Optional[str]:
         try:
@@ -111,12 +151,20 @@ class ProfileSelf(Image):
             log.exception("buddy_name failed to return")
             return None
 
+    @property
+    def team(self) -> Optional[int]:
+        if isinstance(self._team, int):
+            return self._team
+        else:
+            self._team = self.get_team()
+            return self._team
+
     @property
     def travel_km(self) -> Optional[decimal.Decimal]:
         try:
             result = (
                 re.search(
-                    self.pattern_lookups[self.locale.language]["travel_km"],
+                    self.pattern_lookups[self.locale.language]["travel_km"] + "\s?[;:：]?\n(.+)",
                     self.text_found[0].description,
                     re.IGNORECASE,
                 )[1]
@@ -132,7 +180,7 @@ class ProfileSelf(Image):
     def capture_total(self) -> Optional[int]:
         try:
             result = re.search(
-                self.pattern_lookups[self.locale.language]["capture_total"],
+                self.pattern_lookups[self.locale.language]["capture_total"] + "\s?[;:：]?\n(.+)",
                 self.text_found[0].description,
                 re.IGNORECASE,
             )[1].strip()
@@ -145,7 +193,8 @@ class ProfileSelf(Image):
     def pokestops_visited(self) -> Optional[int]:
         try:
             result = re.search(
-                self.pattern_lookups[self.locale.language]["pokestops_visited"],
+                self.pattern_lookups[self.locale.language]["pokestops_visited"]
+                + "\s?[;:：]?\n(.+)",
                 self.text_found[0].description,
                 re.IGNORECASE,
             )[1].strip()
@@ -158,7 +207,7 @@ class ProfileSelf(Image):
     def total_xp(self) -> Optional[int]:
         try:
             result = re.search(
-                self.pattern_lookups[self.locale.language]["total_xp"],
+                self.pattern_lookups[self.locale.language]["total_xp"] + "\s?[;:：]?\n(.+)",
                 self.text_found[0].description,
                 re.IGNORECASE,
             )[1].strip()
@@ -171,7 +220,7 @@ class ProfileSelf(Image):
     def start_date(self) -> Optional[datetime.date]:
         try:
             result = re.search(
-                self.pattern_lookups[self.locale.language]["start_date"],
+                self.pattern_lookups[self.locale.language]["start_date"] + "\s?[;:：]?\n(.+)",
                 self.text_found[0].description,
                 re.IGNORECASE,
             )[1]
